| Title: | What the Package Does (Title Case) |
|---|---|
| Description: | More about what it does (maybe more than one line) Use four spaces when indenting paragraphs within the Description. |
| Authors: | Who wrote it |
| Maintainer: | The package maintainer <[email protected]> |
| License: | What license is it under? |
| Version: | 0.1.1 |
| Built: | 2026-05-14 05:43:29 UTC |
| Source: | https://github.com/Bioconductor/BiocResourceStats |
Quantify topic occurence in *Hub resources and combine package related resources
HubHits(topics, pkg_pattern, hub = c("ExperimentHub", "AnnotationHub")) prop.HubHits(x) ## S3 method for class 'HubHits' print(x)HubHits(topics, pkg_pattern, hub = c("ExperimentHub", "AnnotationHub")) prop.HubHits(x) ## S3 method for class 'HubHits' print(x)
topics |
|
pkg_pattern |
|
hub |
|
x |
|
HubHits: A HubHits instance
prop.HubHits: The proportion of search hits to all resources in the specified hub
print(HubHits):
prop.HubHits():
if (interactive()) { et <- HubHits(c("cancer", "tumor"), "curated*", hub = "ExperimentHub") } if (interactive()) { # proportion of hits in all *Hub prop.HubHits(et) } if (interactive()) { # print HubHits et }if (interactive()) { et <- HubHits(c("cancer", "tumor"), "curated*", hub = "ExperimentHub") } if (interactive()) { # proportion of hits in all *Hub prop.HubHits(et) } if (interactive()) { # print HubHits et }